@@ -45,6 +45,9 @@ try:
     import features.chatbot.chatbot.start_chatbot_small as chatbot_sml
     import features.chatbot.chatbot.load_chatbot_models as load_ch_model
     import features.chatbot.todo.make_todo
+    import features.chatbot.todo.read_notes_if_exist
+    import features.chatbot.todo.delete_todo
+
 except Exception as e:
     from JarvisAI.features.weather import weather as wea
     from JarvisAI.features.website_open import website_open
@@ -68,7 +71,7 @@ except Exception as e:
     from JarvisAI.features.chatbot.chatbot import start_chatbot_large as chatbot_lrg
     from JarvisAI.features.chatbot.chatbot import start_chatbot_small as chatbot_sml
     from JarvisAI.features.chatbot.chatbot import load_chatbot_models as load_ch_model
-    from JarvisAI.features.chatbot.todo import make_todo
+    from JarvisAI.features.chatbot.todo import make_todo, read_notes_if_exist, delete_todo
 
 
 class JarvisAssistant:
@@ -501,57 +504,40 @@ class JarvisAssistant:
             print("Exiting now, try again...")
         return chatbot_lrg(input_text, self.chatbot_model)
 
-    # def show_me_my_list(self):
-    #     """
-    #     chatbot_large needs to be set True
-    #     obj = JarvisAssistant(..., chatbot_large=True)
-    #     """
-    #     user_data = self.jarvisai_api.get_user_raw_data(self.token)[1]
-    #     print(user_data)
-    #     my_list = user_data['data']['raw_data'].replace("'", '"')
-    #     my_list = json.loads(my_list).get('user_list', [])
-    #     return my_list
-    #
-    # def create_new_list(self, input_text: str = 'add milk in my shopping list'):
-    #     list_name, items = make_todo(input_text, question_answering_model=self.chatbot_model[
-    #         'intent_model'].question_answering)
-    #
-    #     dict_data = {
-    #         'user_list': [
-    #             {
-    #                 list_name: items
-    #             }
-    #         ]
-    #     }
-    #     status, _ = self.jarvisai_api.update_user_data(self.token, dict_data)
-    #     if status == 200:
-    #         msg = "Items added successfully"
-    #         return True, msg
-    #     else:
-    #         msg = "Something went wrong, contact developer."
-    #         return False, msg
-    #
-    # def delete_particular_list(self):
-    #     my_list = self.show_me_my_list()
-    #     try:
-    #         msg = f"\n\nYou have {len(my_list)} list, Enter respected number to delete entire list"
-    #         self.text2speech(msg)
-    #         for index, list_name in enumerate(my_list):
-    #             print(index, ": ", list(list_name.keys())[0])
-    #         index = input("Enter List Number: ")
-    #         my_list = my_list.pop(index)
-    #         dict_data = {
-    #             'user_list': my_list
-    #         }
-    #         status_update, _ = self.jarvisai_api.update_user_data(self.token, dict_data)
-    #         if status_update == 200:
-    #             msg = "List Updated successfully"
-    #             return True, msg
-    #         else:
-    #             msg = "Something went wrong, contact developer."
-    #             return False, msg
-    #     except Exception as e:
-    #         return False, e
+    def show_me_my_list(self):
+        """
+        Shows your current list data in dictionary if exist
+        parameter:
+        return:
+            data: dictionary containing user list data
+        """
+        data = read_notes_if_exist()
+        return data
+
+    def create_new_list(self, input_text: str = 'add milk in my shopping list'):
+        """
+        It create new list by identifying list name and list data from user input
+        parameter:
+            input_text: str (Example: 'add milk in my shopping list')
+        return:
+            status: boolean (True for success)
+        """
+        status = make_todo(input_text, question_answering_model=self.chatbot_model[
+            'intent_model'].question_answering)
+        return status
+
+    def delete_particular_list(self, input_text: str = 'delete my shopping list'):
+        """
+        It delete particular list by identifying list name from user input
+        parameter:
+            input_text: str (Example: 'delete my shopping list')
+        return:
+            status: boolean (True for success)
+            msg: str (General Message)
+        """
+        status, msg = delete_todo(input_text, question_answering_model=self.chatbot_model[
+            'intent_model'].question_answering)
+        return status, msg
 
 
 if __name__ == '__main__':
@@ -559,12 +545,13 @@ if __name__ == '__main__':
                           load_chatbot_model=True, high_accuracy_chatbot_model=False,
                           chatbot_large=True)
     print(obj.get_user_data())
-    # print(obj.create_new_list())
-    # print("-----------------------")
-    # print(obj.show_me_my_list())
-    # print(obj.get_user_data())
-
-    # obj = JarvisAssistant()
+    print(obj.show_me_my_list())
+    print(obj.create_new_list())
+    print("-----------------------")
+    print(obj.create_new_list('add medicine in my market list'))
+    print(obj.show_me_my_list())
+    print(obj.delete_particular_list())
+    print(obj.show_me_my_list())
     # obj.jarvisai_detect_hands()
     # print(obj.mic_input_ai())
     # print(obj.text2speech_male())
